Description Usage Format Source Examples
Types of date for activities. There are many different business models and dates that can be used to describe the start and end of activities. It is recommended that each publisher adopts their own consistent approach that provides users with a meaningful indication of the lifespan of an activity.
1 |
A data frame with 4 rows and 6 variables:
codedouble COLUMN_DESCRIPTION
namecharacter COLUMN_DESCRIPTION
descriptioncharacter COLUMN_DESCRIPTION
categorylogical COLUMN_DESCRIPTION
urllogical COLUMN_DESCRIPTION
statuscharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 | {
head(ActivityDateType,10)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.