Description Usage Format Source Examples
This codelists exists to group the Budget Identifier codelist into sectors. It is not used as a codelist in its own right. This is a Non-Core codelist.
1 |
A data frame with 31 rows and 6 variables:
codedouble COLUMN_DESCRIPTION
namecharacter COLUMN_DESCRIPTION
descriptionlogical COLUMN_DESCRIPTION
categorydouble COLUMN_DESCRIPTION
urllogical COLUMN_DESCRIPTION
statuscharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 | {
head(BudgetIdentifierSector,10)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.