Description Usage Format Source Examples
This codelist has been created by IATI following agreements and recommendations of the Tracking Cash and Voucher Assistance (CVA) Working Group. Definitions of the codes have been aligned with the CaLP Glossary:http://www.cashlearning.org/resources/glossary. This is a Non-Core codelist.
1 |
A data frame with 2 rows and 6 variables:
codedouble COLUMN_DESCRIPTION
namecharacter COLUMN_DESCRIPTION
descriptioncharacter COLUMN_DESCRIPTION
categorylogical COLUMN_DESCRIPTION
urllogical COLUMN_DESCRIPTION
statuscharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 | {
head(CashandVoucherModalities,10)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.