Description Usage Format Source Examples
The Country codelist is generated from the ISO 3166-1 part of the ISO 3166 standard. The standard makes allowance, alongside the officially assigned codes, for code elements to be expanded by using either reserved codes or user-assigned codes. IATI currently defines additional codes in the XA -XZ range. External URL: http://www.iso.org/iso/home/standards/country_codes.htm
1 |
A data frame with 251 rows and 6 variables:
codecharacter COLUMN_DESCRIPTION
namecharacter COLUMN_DESCRIPTION
descriptionlogical COLUMN_DESCRIPTION
categorylogical COLUMN_DESCRIPTION
urllogical COLUMN_DESCRIPTION
statuscharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.