Description Usage Format Source Examples
Global Coordination Groups - Cluster & Area of Interest Official Names and Codes (Beta) Contains IASC designated Global Clusters and Areas of Responsibility. Global Clusters and Areas of Responsibility (AoR) were defined to enable more predictable leadership in situations of humanitarian emergency. The content includes the Preferred Term to be used for each Cluster and AoR, the Acronym (3-letter cluster code), the Group to which the term belongs (defining whether it is a Global Cluster or AoR) and the website URL. Both the Google Spreadsheet and CSV versions contain HXL hashtags. For more information, please visit http://vocabulary.unocha.org/
1 |
A data frame with 16 rows and 9 variables:
HRinfo IDcharacter COLUMN_DESCRIPTION
Preferred Termcharacter COLUMN_DESCRIPTION
Preferred Term (fr)character COLUMN_DESCRIPTION
ACRONYMcharacter COLUMN_DESCRIPTION
Group Typecharacter COLUMN_DESCRIPTION
Homepagecharacter COLUMN_DESCRIPTION
Date Created (Post Date)character COLUMN_DESCRIPTION
Updated datecharacter COLUMN_DESCRIPTION
Notescharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 | {
head(HumCluster,10)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.