Description Usage Format Source Examples
This is a list of organisation identifiers that is maintained by the IATI Secretariat. The prefix for organisations on this list is XI-IATI If a bona fide organisation is not registered with any recognised or appropriate registration agency (http://iatistandard.org/202/codelists/OrganisationRegistrationAgency/) they should contact the IATI Technical Team who will exceptionally allocate an organisation identifier using the XI-IATI prefix.
While some of these identifiers have been derived from DAC codes, this ‘meaning’ is not carried forward. i.e. IATI generated identifiers have no intrinsic meaning. For general guidance about constructing Organisation Identifiers, please see http://iatistandard.org/organisation-identifiers/
1 |
A data frame with 39 rows and 6 variables:
codecharacter COLUMN_DESCRIPTION
namecharacter COLUMN_DESCRIPTION
descriptioncharacter COLUMN_DESCRIPTION
categorylogical COLUMN_DESCRIPTION
urlcharacter COLUMN_DESCRIPTION
statuscharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 | {
head(IATIOrganisationIdentifier,10)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.