Description Usage Format Source Examples
IATI codes for the role of an organisation within an activity. An organisation can play more than one role within an activity. This is a Core codelist.
1 |
A data frame with 4 rows and 6 variables:
codedouble COLUMN_DESCRIPTION
namecharacter COLUMN_DESCRIPTION
descriptioncharacter COLUMN_DESCRIPTION
categorylogical COLUMN_DESCRIPTION
urllogical COLUMN_DESCRIPTION
statuscharacter COLUMN_DESCRIPTION
https://iatistandard.org/en/iati-standard/203/codelists/
1 2 3 | {
head(OrganisationRole,10)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.